@@ -3,4 +3,5 @@ utils::globalVariables(c("x", "y", "z", "value", ".data", "count",
                          "time", "time_period", "type", "subtype",
                          "alpha", "var_upper_bound", ".",
                          "window", "point_estimate", "lower_95", "upper_95",
-                         "lower_90", "upper_90", "obs_density", "object", "data"))
+                         "lower_90", "upper_90", "obs_density", "object", "data", "powers",
+                         "fx", "hi", "lo", "mmean", "obs", "r", "W_mask"))
