@@ -75,7 +75,7 @@ plot.hyperframe <- function(x, ..., col, time_col = "time", range, lim = NA, mai
 
       gg <- ggplot2::ggplot(data = df, aes(x = longitude, y = latitude)) +
         ggplot2::geom_point(shape = 1, size = 1.5) +
-        ggplot2::coord_quickmap() +
+        ggplot2::coord_fixed() +
         ggplot2::geom_polygon(data = polygon_df, aes(x = longitude, y = latitude), fill = NA, color = "black") +
         ggthemes::theme_map() +
         ggplot2::ggtitle(paste0(main, "\n(Time Period ", time_vis, ")")) +
@@ -130,7 +130,7 @@ plot.hyperframe <- function(x, ..., col, time_col = "time", range, lim = NA, mai
 
     gg <- ggplot2::ggplot(data = df, aes(x = longitude, y = latitude)) +
       ggplot2::geom_point(shape = 1, size = 1.5) +
-      ggplot2::coord_quickmap() +
+      ggplot2::coord_fixed() +
       ggplot2::geom_polygon(data = polygon_df, aes(x = longitude, y = latitude), fill = NA, color = "black") +
       ggthemes::theme_map() +
       ggplot2::ggtitle(paste0(paste0(main, collapse = ", "), "\n(Time period ", time_vis, ")")) +
@@ -161,7 +161,7 @@ plot.hyperframe <- function(x, ..., col, time_col = "time", range, lim = NA, mai
 
       gg <- ggplot2::ggplot(data = df, aes(x = longitude, y = latitude)) +
         ggplot2::geom_point(shape = 1, size = 1.5) +
-        ggplot2::coord_quickmap() +
+        ggplot2::coord_fixed() +
         ggplot2::geom_polygon(data = polygon_df, aes(x = longitude, y = latitude), fill = NA, color = "black") +
         ggthemes::theme_map() +
         ggplot2::ggtitle(paste0(main, "\n(Time Periods ", time_vis[1], " - ", time_vis[length(time_vis)], ")")) +
@@ -187,7 +187,7 @@ plot.hyperframe <- function(x, ..., col, time_col = "time", range, lim = NA, mai
 
       gg <- ggplot2::ggplot(data = df, aes(x = longitude, y = latitude)) +
         ggplot2::geom_point(shape = 1, size = 1.5) +
-        ggplot2::coord_quickmap() +
+        ggplot2::coord_fixed() +
         ggplot2::geom_polygon(data = polygon_df, aes(x = longitude, y = latitude), fill = NA, color = "black") +
         ggthemes::theme_map() +
         ggplot2::ggtitle(paste0(main, "\n(Time Periods ", time_vis[1], " - ", time_vis[length(time_vis)], ")")) +
@@ -225,7 +225,7 @@ plot.hyperframe <- function(x, ..., col, time_col = "time", range, lim = NA, mai
 
     gg <- ggplot2::ggplot(data = df, aes(x = longitude, y = latitude)) +
       ggplot2::geom_point(shape = 1, size = 1.5) +
-      ggplot2::coord_quickmap() +
+      ggplot2::coord_fixed() +
       ggplot2::geom_polygon(data = polygon_df, aes(x = longitude, y = latitude), fill = NA, color = "black") +
       ggthemes::theme_map() +
       ggplot2::ggtitle(paste0(paste0(main, collapse = ", "),
